@@ -186,10 +186,6 @@ class Executor:
 
             # выкачать файл GET-запросом
             r = requests.request(method="GET", url=params, cookies=cookies, timeout=self.timeout)
-
-            logging.info("Request: %s", params)
-            logging.info("Headers: %s", r.request.headers)
-            logging.info("Response: %s", r.status_code)
             return r
         elif method == "PUT":
             cookies = {'session': self.session_id}
@@ -203,13 +199,8 @@ class Executor:
                                      'Upload-Position': "0",
                                      'Last-Part': "1"
                                         })
-                logging.info("Request: %s" % file)
-                logging.info("Headers: %s" % r.request.headers)
-                logging.info("Response: %s" % r.status_code)
             return r
         else:
-            logging.info("Request: %s" % params)
-
             # Request headers
             headers = {
                 'Content-Type': 'application/json',
@@ -298,22 +289,15 @@ class Executor:
             # Check for invalid control characters in response
             try:
                 response = r.json()
-                logging.info("Headers: %s", r.request.headers)
-                if request_code == 203 and request_state == 6:
-                    # fix issue with UnicodeEncodeError for admin get_user_list
-                    logging.info("Response: %s\n", str(response).encode("utf-8"))
-                else:
-                    logging.info("Response: %s\n", response)
+
             except json.decoder.JSONDecodeError as e:
                 logging.exception("EXCEPTION!!! json.decoder.JSONDecodeError:")
                 logging.exception(e)
-                logging.info("Deleting Invalid control characters from response...")
                 str_response = r.text
                 for i in INVALID_CONTROL_CHARACTERS:
                     str_response = str_response.replace(i, '')
                 json_acceptable_string = str_response.replace("'", "\"")
                 response = json.loads(json_acceptable_string)
-                logging.info("Assertions...")
                 error_handler.request_asserts(response, r)
                 return response
 
