@@ -3,10 +3,9 @@
 """ Часто используемые служебные функции """
 from typing import List, Dict, Tuple
 from itertools import count
-import traceback
 import logging
 import time
-
+from .exceptions import ParseError, CubeNotFoundError, ScenarioError
 
 class Helper:
     def __init__(self, sc):
@@ -20,7 +19,7 @@ class Helper:
 
     def get_cube_id(self, cubes_list: List, cube_name: str) -> [str, bool]:
         """
-        Получить id мультисферы
+        Получить id мультисферы (куба).
         :param cubes_list: список мультисфер
         :param cube_name: название мультисферы
         :return: id мультисферы
@@ -28,11 +27,11 @@ class Helper:
         for cube in cubes_list:
             if cube["name"] == cube_name:
                 return cube["uuid"]
-        raise ValueError("No such cube in cubes list: %s\n%s" % (cube_name, traceback.format_exc()))
+        raise ValueError("No such cube \"{}\" in cubes list!".format(cube_name))
 
     def get_measure_or_dim_id(self, multisphere_data: Dict, measure_dim: str, name) -> [str, bool]:
         """
-        Получить id факта или размерности
+        Получить id факта/размерности по имени.
         :param multisphere_data: рабочая область мультисферы
         :param measure_dim: "facts" / "dimensions"
         :param name: название размерности / факта
@@ -41,11 +40,12 @@ class Helper:
         for item in multisphere_data[measure_dim]:
             if item["name"].rstrip() == name.rstrip():
                 return item["id"]
-        logging.error("No such %s: %s\n%s", measure_dim[:-1], name, traceback.format_exc())
-        logging.error("APPLICATION STOPPED!!!")
+        error_msg = "No such {}: {}".format(measure_dim[:-1], name)
+        logging.exception(error_msg)
+        logging.info("APPLICATION STOPPED")
         if self.jupiter:
-            return "ERROR!!! No such %s: %s\n%s" % (measure_dim[:-1], name, traceback.format_exc())
-        raise ValueError("ERROR!!! No such %s: %s\n%s" % (measure_dim[:-1], name, traceback.format_exc()))
+            return "ERROR!!! {}".format(error_msg)
+        raise ValueError("ERROR!!! {}".format(error_msg))
 
     def get_dim_id(self, multisphere_data: Dict, name: str, cube_name: str) -> [str, bool]:
         """
@@ -59,7 +59,7 @@ class Helper:
             if item["name"].rstrip() == name.rstrip():
                 return item["id"]
         logging.error("Dimension name [%s] is not valid for Multisphere [%s]", name, cube_name)
-        logging.error("APPLICATION STOPPED!!!")
+        logging.info("APPLICATION STOPPED")
         if self.jupiter:
             return "ERROR!!! Dimension name [%s] is not valid for Multisphere [%s]" % (name, cube_name)
         raise ValueError("ERROR!!! Dimension name [%s] is not valid for Multisphere [%s]" % (name, cube_name))
@@ -72,11 +72,12 @@ class Helper:
         :param cube_name: название текущей мультисферы
         :return: id факта
         """
+        name = name.strip()
         for item in multisphere_data["facts"]:
-            if item["name"].rstrip() == name.rstrip():
+            if item["name"].strip() == name:
                 return item["id"]
         logging.error("Measure name [%s] is not valid for Multisphere [%s]", name, cube_name)
-        logging.error("APPLICATION STOPPED!!!")
+        logging.info("APPLICATION STOPPED")
         if self.jupiter:
             return "ERROR!!! Measure name [%s] is not valid for Multisphere [%s]" % (name, cube_name)
         raise ValueError("ERROR!!! Measure name [%s] is not valid for Multisphere [%s]" % (name, cube_name))
@@ -87,28 +88,30 @@ class Helper:
         :param name: Вид факта
         :return: Вид факта (id)
         """
-        measure_types = {"Значение": 0,
-                         "Процент": 1,
-                         "Ранг": 2,
-                         "Количество уникальных": 3,
-                         "Среднее": 4,
-                         "Отклонение": 5,
-                         "Минимум": 6,
-                         "Максимум": 7,
-                         "Изменение": 8,
-                         "Изменение в %": 9,
-                         "Нарастающее": 10,
-                         "ABC": 11,
-                         "Медиана": 12,
-                         "Количество": 13,
-                         "UNKNOWN": 14
-                         }
+        measure_types = {
+            "Значение": 0,
+            "Процент": 1,
+            "Ранг": 2,
+            "Количество уникальных": 3,
+            "Среднее": 4,
+            "Отклонение": 5,
+            "Минимум": 6,
+            "Максимум": 7,
+            "Изменение": 8,
+            "Изменение в %": 9,
+            "Нарастающее": 10,
+            "ABC": 11,
+            "Медиана": 12,
+            "Количество": 13,
+            "UNKNOWN": 14
+        }
         if name not in measure_types:
-            logging.error("ERROR!!! No such measure type: %s\n", name, traceback.format_exc())
-            logging.error("APPLICATION STOPPED!!!")
+            error_msg = "ERROR!!! No such measure type: {}".format(name)
+            logging.exception(error_msg)
+            logging.info("APPLICATION STOPPED")
             if self.jupiter:
-                return "ERROR!!! No such measure type: %s\n" % name
-            raise ValueError("ERROR!!! No such measure type: %s\n" % name)
+                return error_msg
+            raise ValueError(error_msg)
         return measure_types[name]
 
     def join_splited_measures(self, formula_lst: List, join_iterations: int):
@@ -180,24 +183,23 @@ class Helper:
         # рекурсивно вызвать join_splited_measures()
         return self.join_splited_measures(formula_lst, join_iterations)
 
-    def get_scenario_data(self, scenario_data: Dict, scenario_name: str) -> [str, bool]:
+    def get_scenario_data(self, scenario_data: Dict, scenario_name: str) -> str:
         """
         Получение id сценария по имени сценария
-        :param scenario_data: (Dict) данные по всем сценариям, можно получить в модуле Manager, command: "script",
-                            state: "list"
+        :param scenario_data: (Dict) данные по всем сценариям, можно получить с помощью команды ("script", "list")
         :param scenario_name: (str) название сценария
         :return: id сценария
         """
         script_descs = self.parse_result(result=scenario_data, key="script_descs")
-
         for i in script_descs:
-            if i["name"] == scenario_name:
-                return i["uuid"]
-        logging.error("ERROR!!! No such scenario name: %s", scenario_name)
-        logging.error("APPLICATION STOPPED!!!")
+            if i.get("name") == scenario_name:
+                return i.get("uuid")
+        error_msg = 'Сценарий с именем "{}" не найден!'.format(scenario_name)
+        logging.error(error_msg, exc_info=True)
+        logging.info("APPLICATION STOPPED")
         if self.jupiter:
-            return "ERROR!!! No such scenario name: %s" % scenario_name
-        raise ValueError("ERROR!!! No such scenario name: %s" % scenario_name)
+            return error_msg
+        raise ScenarioError(error_msg)
 
     def wait_scenario_layer_loaded(self, sc_layer: str, timeout: int) -> [Tuple, str]:
         """
@@ -219,15 +221,13 @@ class Helper:
                     raise TimeoutError("Timeout while waiting loading scenario layer!")
                 except Exception as e:
                     logging.exception("EXCEPTION!!! %s", e)
-                    logging.exception("APPLICATION STOPPED")
+                    logging.info("APPLICATION STOPPED")
                     self.sc.current_exception = "EXCEPTION!!! %s" % e
                     if self.jupiter:
                         return self.sc.current_exception
                     raise
 
             progress = self.sc.execute_manager_command(command_name="script", state="run_progress", layer_id=sc_layer)
-            logging.info(progress)
-
             total_steps = self.parse_result(result=progress, key="total_steps_count")
             finished_steps = self.parse_result(result=progress, key="finished_steps_count")
 
@@ -235,30 +235,33 @@ class Helper:
 
     def parse_result(self, result: Dict, key: str, nested_key: str = None):
         """
-        Парсит и проверяет на ошибки ответ в виде ['queries'][0]['command']['значение']['['необязательное значение']
+        Парсит и проверяет на ошибки ответ в виде ['queries'][0]['command']['значение']['необязательное значение'].
         :param result: (Dict) нераспарсенный ответ от API
         :param key: (str) ключ, значение которого нужно распарсить
         :param nested_key: (str) вложенный ключ, значение которого нужно распарсить
         :return: итоговое значение
         """
+        base_error_msg = "ERROR while parsing response: ['queries'][0]['command']"
         request_queries = result.get("queries")
         request_queries = next(iter(request_queries))
         request_command = request_queries.get("command")
         value = request_command.get(key)
         if value is None:
-            logging.error("ERROR while parsing response: ['queries'][0]['command']['%s']", key)
-            logging.error("APPLICATION STOPPED")
+            error_msg = "{}['{}']".format(base_error_msg, key)
+            logging.error(error_msg)
+            logging.info("APPLICATION STOPPED")
             if self.jupiter:
-                return "ERROR while parsing response: ['queries'][0]['command']['%s']" % key
-            raise
+                return error_msg
+            raise ParseError(error_msg)
         if nested_key is not None:
             nested_value = value.get(nested_key)
             if nested_value is None:
-                logging.error("ERROR while parsing response: ['queries'][0]['command']['%s']['%s']", key, nested_key)
-                logging.error("APPLICATION STOPPED")
+                error_msg = "{}['{}']['{}']".format(base_error_msg, key, nested_key)
+                logging.error(error_msg)
+                logging.info("APPLICATION STOPPED")
                 if self.jupiter:
-                    return "ERROR while parsing response: ['queries'][0]['command']['%s']['%s']" % (key, nested_key)
-                raise
+                    return error_msg
+                raise ParseError(error_msg)
             return nested_value
         return value
 
@@ -327,16 +330,3 @@ class Helper:
                                                   num=next(gen))
             data = self.parse_result(result=result, key="data")
         return result
-
-    # def get_default_args(func) -> Dict:
-    #     """
-    #     Получение дефолтных параметров функции
-    #     :param func: название функции
-    #     :return: (Dict) словарь параметров функции
-    #     """
-    #     signature = inspect.signature(func)
-    #     return {
-    #         k: v.default
-    #         for k, v in signature.parameters.items()
-    #         if v.default is not inspect.Parameter.empty
-    #     }
